PyKEEN
======
PyKEEN (Python KnowlEdge EmbeddiNgs) is a package for training and evaluating knowledge graph embeddings (KGEs).

The system has a modular architecture, and can be configured by the user through the command line interface.

Installation is as easy as getting the code from `PyPI <https://pypi.python.org/pypi/pykeen>`_ with
:code:`python3 -m pip install pykeen`

Citation
--------
If you use PyKEEN in your work, please cite [1]_:

.. [1] Ali, M., *et al.* (2018). `BioKEEN: A library for learning and evaluating biological knowledge graph embeddings
       <https://zenodo.org/badge/latestdoi/136345023>`_.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   overview
   installation

.. toctree::
   :maxdepth: 2
   :caption: Models
   :name: data

   kge_models

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
